% ex_lm_lqg.m
% pouso do mdulo lunar com controle LQG.

% Especificaes do mdulo
m = 4800;

% Especificaes da Lua
g = 1.625;

% Especificaes dos Propulsores
Ehmax = 45000;
Edmax = 45000;
Eo = m*g;
Eopc = 100*Eo/Ehmax;
W = 450*eye(2);

% Especificaes do rastreamento
V = 15*eye(2);

% Modelo contnuo do mdulo
A = [0 1 0 0; 0 0 0 0; 0 0 0 1; 0 0 0 0];
B = [0 0; 1/m 0; 0 0; 0 1/m];
C = [1 0 0 0; 0 0 1 0];
D = [0 0; 0 0];
Sc  = ss(A,B,C,D);
Scx = ss(A,B,eye(4),zeros(4,2));

% Modelo discretizado
T = 0.1;
Sd  = c2d(Sc,T,'zoh');
Sdx = c2d(Scx,T,'zoh');

% Filtro de Kalman

% Sistema aumentado para projetar o filtro (Veja '>> doc kalman' no Matlab)
Phi = Sd.a;
Gamma = Sd.b;
Lambda = Gamma;
H = zeros(2,2);
Sdaug = ss(Phi,[Gamma Lambda],C,[D H],T); 

[KF,L,P]=kalman(Sdaug,eye(2),W,V); 

% Regulador linear quadrtico

% Matrizes de Peso
q = 500;
r = 1; 

% Simulao Base
xo = [1000 0 -1000 0];

Q = q*eye(4); R = r*eye(2);
[K,X,zc] = dlqr(Phi,Gamma,Q,R);
sim('ex_lm_lqg_sim');
tbsim = tsim; xbsim = xsim; ubsim = usim;

% Trajetria para a simulao base
figure(1);
plot(ysim(:,2),ysim(:,1),'r.','markersize',8)
hold on
plot(xsim(:,3),xsim(:,1),'b-','linewidth',2)
plot(ysim_clean(:,2),ysim_clean(:,1),'b--','linewidth',1)
hold off
axis([-1100 100 -100 1100])
grid on
set(gca,'fontname','times','fontsize',16)
xlabel('distncia  base d (m)');
ylabel('altitude h (m)')
legend('trajetria medida','trajetria efetiva (no medida)','trajetria sem rudo (fictcia)')

% Sada do controlador
figure(2); 
plot(tsim,(ulqg(:,1)+Eo)*100/Ehmax,'-','color',[0 0 1],'linewidth',2)
hold on
plot(tsim,ulqg(:,2)*100/Edmax,'-','color',[1 0 0],'linewidth',2)
plot(tsim,(usim_clean(:,1)+Eo)*100/Ehmax,'--','color',[0 0 1],'linewidth',1)
plot(tsim,usim_clean(:,2)*100/Edmax,'--','color',[1 0 0],'linewidth',1)
hold off
grid on
set(gca,'fontname','times','fontsize',12)
xlabel('t (s)')
ylabel('Empuxo (% do empuxo mximo)')
legend({'E_h calculado','E_d calculado','E_h sem rudo (fictcio)','E_d sem rudo (fictcio)'},'interpreter','tex');

% Estado
figure(3); 
[haxis,hcurve1,hcurve2] = plotyy(tsim,[ xsim(:,[1 3]) xkf(:,[1 3]) xsim_clean(:,[1 3]) ],tsim,[ xsim(:,[2 4]) xkf(:,[2 4]) xsim_clean(:,[2 4]) ]);
set(hcurve1(1),'linestyle','-','color',[0 0 1],'linewidth',2)
set(hcurve1(2),'linestyle','-','color',[1 0 0],'linewidth',2)
set(hcurve1(3),'linestyle','-','color',[0 0 1],'linewidth',1)
set(hcurve1(4),'linestyle','-','color',[1 0 0],'linewidth',1)
set(hcurve1(5),'linestyle','--','color',[0 0 1],'linewidth',1)
set(hcurve1(6),'linestyle','--','color',[1 0 0],'linewidth',1)

set(hcurve2(1),'linestyle','-','color',[0 0 0.6],'linewidth',2)
set(hcurve2(2),'linestyle','-','color',[0.6 0 0],'linewidth',2)
set(hcurve2(3),'linestyle','-','color',[0 0 0.6],'linewidth',1)
set(hcurve2(4),'linestyle','-','color',[0.6 0 0],'linewidth',1)
set(hcurve2(5),'linestyle','--','color',[0 0 0.6],'linewidth',1)
set(hcurve2(6),'linestyle','--','color',[0.6 0 0],'linewidth',1)

set(haxis(1),'xlim',[0 100],'ylim',[-1100 1100],'ytick',[-1000:200:1000]);
set(haxis(2),'xlim',[0 100],'ylim',[-55 55],'ytick',[-50:10:50]);

grid on
set(gca,'fontname','times','fontsize',12)
xlabel('t (s)')
ylabel(haxis(1),'Posies h,d (m)')
ylabel(haxis(2),'Velocidades hor. e vert. (m/s)')
legend([hcurve1(1:2)',hcurve2(1:2)'],...
       'altura h (medida, efetiva, fictcia)',...
       'distncia d (medida, efetiva, fictcia)',...
       'vel. vert. (medida, efetiva, fictcia)',...
       'vel. horiz. (medida, efetiva, fictcia)');

