% ex_lm_test.m
% manobras com o mdulo lunar

% Especificaes do mdulo
m = 4800;

% Especificaes da Lua
g = 1.625;

% Especificaes dos Propulsores
Ehmax = 45000;
Edmax = 45000;
Eo = m*g;
Eopc = 100*Eo/Ehmax;
W = 450*eye(2);

% Especificaes do rastreamento
V = 15*eye(2);

% Modelo contnuo do mdulo
A = [0 1 0 0; 0 0 0 0; 0 0 0 1; 0 0 0 0];
B = [0 0; 1/m 0; 0 0; 0 1/m];
C = [1 0 0 0; 0 0 1 0];
D = [0 0; 0 0];
Sc  = ss(A,B,C,D);
Scx = ss(A,B,eye(4),zeros(4,2));

% Modelo discretizado
T = 0.1;
Sd  = c2d(Sc,T,'zoh');
Sdx = c2d(Scx,T,'zoh');

% Simulao da manobra
xo = [1000 0 -1000 0];

tEh =  [0   5  25  35  40];
Eh  = ([0 -20  20   0  20] + Eopc)/100*Ehmax;
Eh_data = [tEh' Eh'];

tEd = [0   10  20  30 40];
Ed  = [60 -60   0 -60 60]/100*Edmax;
Ed_data = [tEd' Ed'];

sim('ex_lm_test_sim')

% Grficos
figure(1); 
plot(tsim,usim_calc(:,1)*100/Ehmax,'color',[0 0 0.6],'linewidth',2)
hold on
plot(tsim,usim_calc(:,2)*100/Edmax,'color',[0.6 0 0],'linewidth',2)
plot(tsim,(usim(:,1)+Eo)*100/Ehmax,'.','color',[0 0 1],'markersize',8)
plot(tsim,usim(:,2)*100/Edmax,'.','color',[1 0 0])
hold off
grid on
set(gca,'fontname','times','fontsize',12)
xlabel('t (s)')
ylabel('Empuxo (% do empuxo mximo)')
legend({'E_h demandado','E_d demandado','E_h efetivo (no medido)','E_d efetivo (no medido)'},'interpreter','tex');




figure(2);
plot(ysim(:,2),ysim(:,1),'r.','markersize',8)
hold on
plot(xsim(:,3),xsim(:,1),'b-','linewidth',2)
plot(ysim_clean(:,2),ysim_clean(:,1),'b--','linewidth',1)
hold off
axis([-1100 100 -100 1100])
grid on
set(gca,'fontname','times','fontsize',16)
xlabel('distncia  base d (m)');
ylabel('altitude h (m)')
legend('(h,d) medido','(h,d) efetivo (no medido)','(h,d) sem rudo (fictcio)')



